//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : adcBuff.cpp
//
//	Project	 : PCM-MIO Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/16/18	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmmioDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define DEVICE      1

int _tmain(int argc, _TCHAR* argv[])
{
    unsigned int chanBuf[] = { 1, 1, 5, 7, 3, 8, 10, 11, 12, 8, 14, 14, 0xFF };
    unsigned short buffer[sizeof(chanBuf) - 1];
    float temp;
    int dllReturn = SUCCESS;

    printf("PCM-MIO Application : adcBuff\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    if (argc > 1)
    {
        printf("Usage error:\n");
        printf("  adcBuff\n");
        exit(1);
    }

    dllReturn = InitializeSession(DEVICE);

    if (dllReturn)
    {
        printf("Error initializing device.\n");
        exit(dllReturn);
    }
    else   
    {
        printf("Device opened.\n");
    }

    // set all channels for -10V to +10V
    for (int ch = 0; ch < 16; ch++) {
        dllReturn = AdcSetChannelMode(DEVICE, ch, ADC_SINGLE_ENDED, ADC_BIPOLAR, ADC_TOP_10V);

        if (dllReturn)
        {
            printf("Error configuring ADC channel %d.\n", ch);
            exit(dllReturn);
        }
        else
            printf("Channel %d configured.\n", ch);
    }

    printf("\n");

    // buffered channel conversions
    dllReturn = AdcBufferedChannelConversions(DEVICE, chanBuf, buffer);

    for (int i = 0; i < (sizeof(chanBuf) / sizeof(unsigned int)) - 1; i++)
    {
        AdcConvertToVolts(DEVICE, chanBuf[i], buffer[i], &temp);
        printf("ADC Channel %d voltage read is %.5f.\n", chanBuf[i], temp);
    }

    dllReturn = CloseSession(DEVICE);

    if (dllReturn)
    {
        printf("Error closing device.\n");
        exit(dllReturn);
    }
    else
    {
        printf("Device closed.\n");
    }

    return(0);
}
