//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : dacBuff.cpp
//
//	Project	 : PCM-MIO Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/16/18	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmmioDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define DEVICE      1

int _tmain(int argc, _TCHAR* argv[])
{
    unsigned short chanBuf[] = { 0, 1, 2, 3, 4, 5, 6, 7, 0xff };
    float voltBuf[] = { (float)-8.8, (float)-5.5, (float)-3.3, (float)-1.8, (float)1.1, (float)2.2, (float)4.4, (float)9.5 };
    int dllReturn = SUCCESS;

    printf("PCM-MIO Application : dacBuff\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    if (argc > 1)
    {
        printf("Usage error:\n");
        printf("  dacBuff\n");
        exit(1);
    }

    dllReturn = InitializeSession(DEVICE);

    if (dllReturn)
    {
        printf("Error initializing device.\n");
        exit(dllReturn);
    }
    else   
    {
        printf("Device opened.\n");
    }

    // set voltage for all dac channels
    dllReturn = DacBufferedVoltage(DEVICE, chanBuf, voltBuf);

    if (dllReturn)
    {
        printf("Error setting DAC channels.\n");
        exit(dllReturn);
    }
    else
    {
        for (int i = 0; i < 8; i++)
            printf("DAC channel %d voltage set to %.3f\n", chanBuf[i], voltBuf[i]);
    }

    dllReturn = CloseSession(DEVICE);

    if (dllReturn)
    {
        printf("Error closing device.\n");
        exit(dllReturn);
    }
    else
    {
        printf("Device closed.\n");
    }

    return(0);
}
